@@ -1,23 +1,27 @@
 //! @file parser.c
 //! @author J. Marcel van der Veer
-//
+
 //! @section Copyright
-//
-// This file is part of Algol68G - an Algol 68 compiler-interpreter.
-// Copyright 2001-2023 J. Marcel van der Veer <algol68g@xs4all.nl>.
-//
+//!
+//! This file is part of Algol68G - an Algol 68 compiler-interpreter.
+//! Copyright 2001-2024 J. Marcel van der Veer [algol68g@xs4all.nl].
+
 //! @section License
-//
-// This program is free software; you can redistribute it and/or modify it 
-// under the terms of the GNU General Public License as published by the 
-// Free Software Foundation; either version 3 of the License, or 
-// (at your option) any later version.
-//
-// This program is distributed in the hope that it will be useful, but 
-// WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY 
-// or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for 
-// more details. You should have received a copy of the GNU General Public 
-// License along with this program. If not, see <http://www.gnu.org/licenses/>.
+//!
+//! This program is free software; you can redistribute it and/or modify it 
+//! under the terms of the GNU General Public License as published by the 
+//! Free Software Foundation; either version 3 of the License, or 
+//! (at your option) any later version.
+//!
+//! This program is distributed in the hope that it will be useful, but 
+//! WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY 
+//! or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for 
+//! more details. You should have received a copy of the GNU General Public 
+//! License along with this program. If not, see [http://www.gnu.org/licenses/].
+
+//! @section Synopsis 
+//!
+//! Mailloux-type Algol 68 parser driver.
 
 // The Algol 68 grammar is a two level (Van Wijngaarden, "VW") grammar 
 // that incorporates, as syntactical rules, the semantical rules in 
@@ -217,12 +221,10 @@ BOOL_T is_semicolon_less (NODE_T * p)
   case EDOC_SYMBOL:
   case OCCA_SYMBOL:
   case OD_SYMBOL:
-  case UNTIL_SYMBOL:
-    {
+  case UNTIL_SYMBOL: {
       return A68_TRUE;
     }
-  default:
-    {
+  default: {
       return A68_FALSE;
     }
   }
@@ -245,12 +247,10 @@ BOOL_T is_formal_bounds (NODE_T * p)
     case DOTDOT_SYMBOL:
     case INT_DENOTATION:
     case IDENTIFIER:
-    case OPERATOR:
-      {
+    case OPERATOR: {
         return (BOOL_T) (is_formal_bounds (SUB (p)) && is_formal_bounds (NEXT (p)));
       }
-    default:
-      {
+    default: {
         return A68_FALSE;
       }
     }
@@ -279,8 +279,7 @@ BOOL_T is_unit_terminator (NODE_T * p)
   case OUSE_SYMBOL:
   case ESAC_SYMBOL:
   case EDOC_SYMBOL:
-  case OCCA_SYMBOL:
-    {
+  case OCCA_SYMBOL: {
       return A68_TRUE;
     }
   }
@@ -298,8 +297,7 @@ BOOL_T is_loop_keyword (NODE_T * p)
   case TO_SYMBOL:
   case DOWNTO_SYMBOL:
   case WHILE_SYMBOL:
-  case DO_SYMBOL:
-    {
+  case DO_SYMBOL: {
       return A68_TRUE;
     }
   }
@@ -314,12 +312,10 @@ int get_good_attribute (NODE_T * p)
   case UNIT:
   case TERTIARY:
   case SECONDARY:
-  case PRIMARY:
-    {
+  case PRIMARY: {
       return get_good_attribute (SUB (p));
     }
-  default:
-    {
+  default: {
       return ATTRIBUTE (p);
     }
   }
@@ -431,8 +427,7 @@ BOOL_T dont_mark_here (NODE_T * p)
   case SERIAL_CLAUSE:
   case ENQUIRY_CLAUSE:
   case INITIALISER_SERIES:
-  case DECLARATION_LIST:
-    {
+  case DECLARATION_LIST: {
       return A68_TRUE;
     }
   }
@@ -442,7 +437,6 @@ BOOL_T dont_mark_here (NODE_T * p)
 void a68_parser (void)
 {
 // Tokeniser.
-  int renum;
   FILE_SOURCE_OPENED (&A68_JOB) = A68_TRUE;
   announce_phase ("initialiser");
   A68_PARSER (error_tag) = (TAG_T *) new_tag ();
@@ -477,7 +471,7 @@ void a68_parser (void)
     FILE_SOURCE_OPENED (&A68_JOB) = A68_FALSE;
     prune_echoes (OPTION_LIST (&A68_JOB));
     TREE_LISTING_SAFE (&A68_JOB) = A68_TRUE;
-    renum = 0;
+    int renum = 0;
     renumber_nodes (TOP_NODE (&A68_JOB), &renum);
   }
 // Now the default precision of LONG LONG modes is fixed.
@@ -487,11 +481,11 @@ void a68_parser (void)
 // Final initialisations.
   if (ERROR_COUNT (&A68_JOB) == 0) {
     if (OPTION_REGRESSION_TEST (&A68_JOB)) {
-      bufcpy (A68 (a68_cmd_name), "a68g", BUFFER_SIZE);
+      a68_bufcpy (A68 (a68_cmd_name), "a68g", BUFFER_SIZE);
       io_close_tty_line ();
-      WRITE (STDERR_FILENO, "[");
-      WRITE (STDERR_FILENO, FILE_INITIAL_NAME (&A68_JOB));
-      WRITE (STDERR_FILENO, "]\n");
+      WRITE (A68_STDERR, "[");
+      WRITE (A68_STDERR, FILE_INITIAL_NAME (&A68_JOB));
+      WRITE (A68_STDERR, "]\n");
     }
     A68_STANDENV = NO_TABLE;
     init_postulates ();
@@ -511,7 +505,7 @@ void a68_parser (void)
     if (ERROR_COUNT (&A68_JOB) == 0) {
       put_refinements ();
     }
-    renum = 0;
+    int renum = 0;
     renumber_nodes (TOP_NODE (&A68_JOB), &renum);
     verbosity ();
   }
@@ -528,7 +522,7 @@ void a68_parser (void)
       LEVEL (A68_STANDENV) = 0;
       top_down_parser (TOP_NODE (&A68_JOB));
     }
-    renum = 0;
+    int renum = 0;
     renumber_nodes (TOP_NODE (&A68_JOB), &renum);
     verbosity ();
   }
@@ -545,7 +539,7 @@ void a68_parser (void)
     announce_phase ("parser phase 2");
     preliminary_symbol_table_setup (TOP_NODE (&A68_JOB));
     bottom_up_parser (TOP_NODE (&A68_JOB));
-    renum = 0;
+    int renum = 0;
     renumber_nodes (TOP_NODE (&A68_JOB), &renum);
     verbosity ();
   }
@@ -561,7 +555,7 @@ void a68_parser (void)
       set_nest (TOP_NODE (&A68_JOB), NO_NODE);
       set_proc_level (TOP_NODE (&A68_JOB), 1);
     }
-    renum = 0;
+    int renum = 0;
     renumber_nodes (TOP_NODE (&A68_JOB), &renum);
     verbosity ();
   }
@@ -600,7 +594,7 @@ void a68_parser (void)
     assign_offsets_table (A68_STANDENV);
     assign_offsets (TOP_NODE (&A68_JOB));
     assign_offsets_packs (TOP_MOID (&A68_JOB));
-    renum = 0;
+    int renum = 0;
     renumber_nodes (TOP_NODE (&A68_JOB), &renum);
     verbosity ();
   }
@@ -748,8 +742,8 @@ MOID_T *new_moid (void)
   HAS_ROWS (z) = A68_FALSE;
   SIZE (z) = 0;
   DIGITS (z) = 0;
-  SIZEC (z) = 0;
-  DIGITSC (z) = 0;
+  SIZE_COMPL (z) = 0;
+  DIGITS_COMPL (z) = 0;
   PORTABLE (z) = A68_TRUE;
   DERIVATE (z) = A68_FALSE;
   NODE (z) = NO_NODE;
@@ -850,8 +844,8 @@ BOOL_T match_string (char *x, char *c, char alt)
 BOOL_T whether (NODE_T * p, ...)
 {
   va_list vl;
-  int a;
   va_start (vl, p);
+  int a;
   while ((a = va_arg (vl, int)) != STOP)
   {
     if (p != NO_NODE && a == WILDCARD) {
@@ -880,9 +874,9 @@ BOOL_T is_one_of (NODE_T * p, ...)
 {
   if (p != NO_NODE) {
     va_list vl;
-    int a;
-    BOOL_T match = A68_FALSE;
     va_start (vl, p);
+    BOOL_T match = A68_FALSE;
+    int a;
     while ((a = va_arg (vl, int)) != STOP)
     {
       match = (BOOL_T) (match | (BOOL_T) (IS (p, a)));
@@ -970,12 +964,10 @@ BOOL_T is_new_lexical_level (NODE_T * p)
   case CONFORMITY_CHOICE:
   case CONFORMITY_IN_PART:
   case CONFORMITY_OUSE_PART:
-  case WHILE_PART:
-    {
+  case WHILE_PART: {
       return A68_TRUE;
     }
-  default:
-    {
+  default: {
       return A68_FALSE;
     }
   }
